@@ -11,7 +11,7 @@ except ImportError:
                                "the constance database backend.")
 
 class Constance(models.Model):
-    key = models.TextField()
+    key = models.CharField(max_length=255, unique=True)
     value = PickledObjectField()
 
     class Meta:
